<?php

App::uses('AppComponent', 'Controller/Component');
App::uses('CakeText', 'Utility');
App::uses('InflectorExt', 'EvInflector.Lib');

class MetaComponent extends AppComponent {

	/**
	 * Sets the view variables for the meta data.
	 *
	 * @param array $data array containing the MetaData
	 * @param string $overrideModel The main model, useful if setting Page content from within a plugin
	 */
	public function set($data, $overrideModel = null) {
		$Model = $this->_controller->{$this->_controller->modelClass};

		if (isset($data['MetaData'])) {
			$this->_controller->set('metaTitle', (isset($data['MetaData']['title']) ? $data['MetaData']['title'] : null));
			$this->_controller->set('metaDescription', (isset($data['MetaData']['description']) ? $data['MetaData']['description'] : null));
			$this->_controller->set('metaKeywords', (isset($data['MetaData']['keywords']) ? $data['MetaData']['keywords'] : null));
		}

		if (empty($data['MetaData']['description'])) {
			if (! empty($data[$Model->alias]['body'])) {
				$this->_controller->set(
					'metaDescription',
					CakeText::truncate(strip_tags($data[$Model->alias]['body']), 200, array('ellipsis' => ''))
				);
			} elseif (! empty($data[$Model->alias]['description'])) {
				$this->_controller->set(
					'metaDescription',
					CakeText::truncate(strip_tags($data[$Model->alias]['description']), 200, array('ellipsis' => ''))
				);
			}
		}

		// override the Model, otherwise plugins will look at their own models
		// for the title when it may actually want to look at 'Page' Model.
		if (! empty($overrideModel)) {
			$this->_controller->loadModel($overrideModel);
			list($pluginName, $modelName) = pluginSplit($overrideModel);
			$Model = $this->_controller->{$modelName};
		}

		// Set the title for layout, either using the meta title, display
		// field, or model name.
		if (isset($data['MetaData']) && !empty($data['MetaData']['title'])) {
			$titleForLayout = $data['MetaData']['title'];
		} elseif (isset($data[$Model->alias][$Model->displayField])) {
			$titleForLayout = $data[$Model->alias][$Model->displayField] . ' | ' . Configure::read('SiteSetting.general.site_title');
		} else {
			$titleForLayout = InflectorExt::pluralize($Model->displayName) . ' | ' . Configure::read('SiteSetting.general.site_title');
		}
		$this->_controller->set('titleForLayout', $titleForLayout);
		// Set title_for_layout for backwards compatibility (CakePhp 2.4.x).
		$this->_controller->set('title_for_layout', $titleForLayout);

		if (!isset($data['MetaData']['description']) || empty($data['MetaData']['description'])) {

			if (isset($data[$Model->alias]['body'])) {
				$this->_controller->set('metaDescription', CakeText::Truncate(strip_tags($data[$Model->alias]['body']), 200));
			} elseif (isset($data[$Model->alias]['description'])) {
				$this->_controller->set('metaDescription', CakeText::Truncate(strip_tags($data[$Model->alias]['description']), 200));
			}
		}

		return;
	}
}
